![Yooink text logo](https://raw.githubusercontent.com/Waveform-Analytics/yooink/main/assets/final-text-sm.png)

# yooink

A Python package to access Ocean Observatories Initiative (OOI) data via 
the m2m (machine to machine) interface. 

## Quick Setup

You can install this package from [PyPI](https://pypi.org/project/yooink/) using:

```bash
pip install yooink
```

## Usage

For more information about how to install and use yooink, check out the 
[yooink documentation site](https://waveform-analytics.github.io/yooink/).

